# Computerlinguistische Analyse des Merlin Corpus (https://merlin-platform.eu/) mit CTAP
# Hilfsskript. Bitte gehen Sie zur Datei ctap-analysis.R
#
# Zarah Weiss, 18.02.2020
# =============================================================================================

# Funktionen
merlin.daten.vorbereitung <- function(df) {
  rval <- df %>% 
    select(-Tags, -Feature_id) %>% 
    spread(Feature_Name, Value) %>% 
    separate("Text_Title", c("Unknown.Meta", "Task.ID", "Test.Languauge",
                             "Test.CEFR.Level", "L1", "Age", "Gender",
                             "CEFR.Score.Overall", "CEFR.Score.Grammatical.Accuracy", 
                             "CEFR.Score.Orthography", "CEFR.Score.Vocabulary.Range",
                             "CEFR.Score.Vocabulary.Control", "CEFR.Score.Coherence_Cohesion", 
                             "CEFR.Score.Sociolinguistics"), sep = "-", 
             remove = F) %>% 
    mutate(CEFR.Score.Overall = case_when(CEFR.Score.Overall == "c2" ~ "c1",
                                          TRUE ~ CEFR.Score.Overall),
           Aufgabe = case_when(
             Task.ID=="1071_120302" ~ "A1: Going swimming",
             Task.ID=="1071_020200" ~ "A1: Request help",
             Task.ID=="1071_030101" ~ "A1: Birth congratulations",
             Task.ID=="1091_0690403"|Task.ID=="1091_0690404" ~ "A2: Ticket offer",
             Task.ID=="1091_0650102" ~ "A2: Pet sitting",
             Task.ID=="1091_0610301" ~ "A2: Housing office",
             Task.ID=="1061_130101" ~ "B1: Visiting a friend",
             Task.ID=="1061_170900" ~ "B1: Happy birthday",
             Task.ID=="1061_110101" ~ "B1: Happy New Year",
             Task.ID=="1023_120301" ~ "B2: Internship",
             Task.ID=="1023_100303" ~ "B2: Aupair complaint",
             Task.ID=="1023_080401" ~ "B2: Aupair request",
             Task.ID=="1031_050300" ~ "C1: Housing situation",
             Task.ID=="1031_010300" ~ "C1: Learning German",
             Task.ID=="1031_030301" ~ "C1: Traditions & Assimilation",
             TRUE~"NA")) %>% 
    select(-Unknown.Meta)
  return(rval)
}

merlin.daten.vorbereitung2 <- function(df.korrigiert, df.nicht.korrigiert) {
  df.korrigiert$Wurde.Korrigiert <- T
  df.nicht.korrigiert$Wurde.Korrigiert <- F
  df <- rbind(df.korrigiert, df.nicht.korrigiert)
  rval <- merlin.daten.vorbereitung(df)
  return(rval)
}

erstelle.boxplot <- function(df, name.des.aktuellen.merkmals) {
  df$Aktuelles.Merkmal <- df[[name.des.aktuellen.merkmals]]
  p1 <- ggplot(data = df, mapping = aes(x = CEFR.Score.Overall, 
                                        y = Aktuelles.Merkmal)) +
    labs(x = "Kompetenzstufen auf der CEFR Skala", y = name.des.aktuellen.merkmals) +
    geom_boxplot(notch = T)
  return(p1)
}

erstelle.boxplot.mit.aufgabensplit <- function(df, name.des.aktuellen.merkmals) {
  df$Aktuelles.Merkmal <- df[[name.des.aktuellen.merkmals]]
  p1 <- ggplot(data = df, mapping = aes(x = CEFR.Score.Overall, 
                                        y = Aktuelles.Merkmal,
                                        fill = Aufgabe)) +
    labs(x = "Kompetenzstufen auf der CEFR Skala", y = name.des.aktuellen.merkmals) +
    geom_boxplot(notch = T) 
  return(p1)
}

erstelle.boxplot.korrigiert.nichtkorrigiert <- function(df, name.des.aktuellen.merkmals) {
  df.tmp <- df %>% filter(!(Task.ID=="1091_0690404"))
  df.tmp$Aktuelles.Merkmal <- df.tmp[[name.des.aktuellen.merkmals]]
  p1 <- ggplot(data = df.tmp, mapping = aes(x = CEFR.Score.Overall, 
                                            y = Aktuelles.Merkmal,
                                            fill = Wurde.Korrigiert)) +
    labs(x = "Kompetenzstufen auf der CEFR Skala", y = name.des.aktuellen.merkmals) +
    geom_boxplot(notch = T)
  return(p1)
}

speichere.boxplot <- function(datei.name, aktueller.plot) {
  ggsave(paste0("plots/",datei.name), aktueller.plot, device = cairo_pdf())
  dev.off()
}